Name
----

gitman
~~~~~~
I started organizing and auto-updating my bio-informatics git clones using
a short ad-hoc bash script that I called `gitman` (Git Manager)


bspman
~~~~~~
Futher `gitman` got bloated into `bspman`, \
**B**\ io-informatics **S**\ cripts **P**\ ackage **Man**\ ager; \
**OR** equally correctly, \
**B**\ ash **S**\ cript **P**\ ackage **Man**\ ager.


pspman
~~~~~~
Since my Mother\ *bored*\ -tongue is python, \
`bspman` had to evolve into `pspman`, \
**P**\ ythonic **S**\ mall **P**\ ackage **Man**\ ager; \
**OR** equally correctly, \
**P**\ ersonal **S**\ imple **P**\ ackage **Man**\ ager.

Later, `pspman` was formally made object-oriented, parallellized \
and is no more *Simple* nor *Small*.
Also,

- it is hazardous to run ``pspman`` with ``sudo`` privileges;
- `pspman` doesn't manage packages. You do.

So, I call it **PS**\ eudo **P**\ ackage **Man**\ ager.
